@@ -8,7 +8,11 @@ def rolling_forecasting(forecasting_model, X, y, n=252, s=63, method = 'standard
     assert X.shape[0] == y.shape[0]
     idx = X.index
     forecasting_series = pd.Series(index=idx, name='prediction')
-    roll = rolling._RollingMechanism(idx, n=n, s=s)
+    if n is None:
+        roll = rolling._ExpandingRollingMechanism(idx, s=s)
+    else:
+        roll = rolling._RollingMechanism(idx, n=n, s=s)
+
     for slice_n, slice_s in roll():
         # Select X
         X_train = X.loc[slice_n].copy()
@@ -26,7 +30,9 @@ def rolling_forecasting(forecasting_model, X, y, n=252, s=63, method = 'standard
         accuracy = accuracy_score(y_test > 0, y_pred > 0)
 
         if display:
-            print('rmse for slice ' + str(slice_s) +' : '+str(rmse))
+            print('training slice ' + str(slice_n))
+            print('testing slice ' + str(slice_s))
+            print('rmse for slice : '+str(rmse))
             print('accuracy')
             print(accuracy)
             print('confusion matrix')
